@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2006 Free Software Foundation, Inc.
+ * Copyright 2006,2011 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -23,6 +23,7 @@
 #ifndef INCLUDED_GR_GOERTZEL_FC_H
 #define INCLUDED_GR_GOERTZEL_FC_H
 
+#include <gr_core_api.h>
 #include <gri_goertzel.h>
 #include <gr_sync_decimator.h>
 
@@ -30,25 +31,30 @@ class gr_goertzel_fc;
 typedef boost::shared_ptr<gr_goertzel_fc> gr_goertzel_fc_sptr;
 
 // public constructor
-gr_goertzel_fc_sptr gr_make_goertzel_fc(int rate, int len, float freq);
+GR_CORE_API gr_goertzel_fc_sptr gr_make_goertzel_fc(int rate, int len, float freq);
 
 /*!
  * \brief Goertzel single-bin DFT calculation.
  * \ingroup dft_blk
  */
-class gr_goertzel_fc : public gr_sync_decimator
+class GR_CORE_API gr_goertzel_fc : public gr_sync_decimator
 {
 private:
-  friend gr_goertzel_fc_sptr gr_make_goertzel_fc (int rate, int len, float freq);
+  friend GR_CORE_API gr_goertzel_fc_sptr gr_make_goertzel_fc (int rate, int len, float freq);
 
   gr_goertzel_fc(int rate, int len, float freq);
   gri_goertzel d_goertzel;
   int          d_len;
+  float	       d_freq;
+  int          d_rate;
 
 public:
   int work(int noutput_items,
 	   gr_vector_const_void_star &input_items,
 	   gr_vector_void_star &output_items);
+
+  void set_freq (float freq);
+  void set_rate (int rate);
 };
 
 #endif /* INCLUDED_GR_GOERTZEL_FC_H */
