@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004 Free Software Foundation, Inc.
+ * Copyright 2004,2010 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -33,7 +33,7 @@
 gr_hilbert_fc_sptr 
 gr_make_hilbert_fc (unsigned int ntaps)
 {
-  return gr_hilbert_fc_sptr (new gr_hilbert_fc (ntaps));
+  return gnuradio::get_initial_sptr(new gr_hilbert_fc (ntaps));
 }
 
 gr_hilbert_fc::gr_hilbert_fc (unsigned int ntaps)
