@@ -26,6 +26,7 @@
 
 #include <gri_fft_filter_ccc_generic.h>
 #include <gri_fft.h>
+#include <volk/volk.h>
 #include <assert.h>
 #include <stdexcept>
 #include <cstdio>
@@ -33,8 +34,9 @@
 #include <fftw3.h>
 
 gri_fft_filter_ccc_generic::gri_fft_filter_ccc_generic (int decimation, 
-							const std::vector<gr_complex> &taps)
-  : d_fftsize(-1), d_decimation(decimation), d_fwdfft(0), d_invfft(0)
+							const std::vector<gr_complex> &taps,
+							int nthreads)
+  : d_fftsize(-1), d_decimation(decimation), d_fwdfft(0), d_invfft(0), d_nthreads(nthreads)
 {
   set_taps(taps);
 }
@@ -43,6 +45,7 @@ gri_fft_filter_ccc_generic::~gri_fft_filter_ccc_generic ()
 {
   delete d_fwdfft;
   delete d_invfft;
+  gri_fft_free(d_xformed_taps);
 }
 
 #if 0
@@ -111,12 +114,28 @@ gri_fft_filter_ccc_generic::compute_sizes(int ntaps)
   if (d_fftsize != old_fftsize){	// compute new plans
     delete d_fwdfft;
     delete d_invfft;
-    d_fwdfft = new gri_fft_complex(d_fftsize, true);
-    d_invfft = new gri_fft_complex(d_fftsize, false);
-    d_xformed_taps.resize(d_fftsize);
+    d_fwdfft = new gri_fft_complex(d_fftsize, true, d_nthreads);
+    d_invfft = new gri_fft_complex(d_fftsize, false, d_nthreads);
+    d_xformed_taps = gri_fft_malloc_complex(d_fftsize);
   }
 }
 
+void
+gri_fft_filter_ccc_generic::set_nthreads(int n)
+{
+  d_nthreads = n;
+  if(d_fwdfft)
+    d_fwdfft->set_nthreads(n);
+  if(d_invfft)
+    d_invfft->set_nthreads(n);
+}
+
+int
+gri_fft_filter_ccc_generic::nthreads() const
+{
+  return d_nthreads;
+}
+
 int
 gri_fft_filter_ccc_generic::filter (int nitems, const gr_complex *input, gr_complex *output)
 {
@@ -134,12 +153,10 @@ gri_fft_filter_ccc_generic::filter (int nitems, const gr_complex *input, gr_comp
     d_fwdfft->execute();	// compute fwd xform
     
     gr_complex *a = d_fwdfft->get_outbuf();
-    gr_complex *b = &d_xformed_taps[0];
+    gr_complex *b = d_xformed_taps;
     gr_complex *c = d_invfft->get_inbuf();
 
-    for (j = 0; j < d_fftsize; j+=1) {	// filter in the freq domain
-      c[j] = a[j] * b[j];
-    } 
+    volk_32fc_x2_multiply_32fc_a(c, a, b, d_fftsize);
     
     d_invfft->execute();	// compute inv xform
 
