@@ -39,9 +39,10 @@ class GR_CORE_API gri_fft_filter_fff_generic
   int                      d_decimation;
   gri_fft_real_fwd	  *d_fwdfft;		// forward "plan"
   gri_fft_real_rev	  *d_invfft;		// inverse "plan"
+  int                      d_nthreads;          // number of FFTW threads to use
   std::vector<float>       d_tail;		// state carried between blocks for overlap-add
-  std::vector<gr_complex>  d_xformed_taps;	// Fourier xformed taps
   std::vector<float>	   d_new_taps;
+  gr_complex              *d_xformed_taps;	// Fourier xformed taps
 
 
   void compute_sizes(int ntaps);
@@ -55,8 +56,10 @@ class GR_CORE_API gri_fft_filter_fff_generic
    * in other blocks for floating point vectors (such as gr_fft_filter_fff).
    * \param decimation The decimation rate of the filter (int)
    * \param taps       The filter taps (float)
+   * \param nthreads   The number of threads for the FFT to use (int)
    */
-  gri_fft_filter_fff_generic (int decimation, const std::vector<float> &taps);
+  gri_fft_filter_fff_generic (int decimation, const std::vector<float> &taps,
+			      int nthreads=1);
   ~gri_fft_filter_fff_generic ();
 
   /*!
@@ -67,6 +70,16 @@ class GR_CORE_API gri_fft_filter_fff_generic
    */
   int set_taps (const std::vector<float> &taps);
   
+  /*!
+   * \brief Set number of threads to use.
+   */
+  void set_nthreads(int n);
+
+  /*!
+   * \brief Get number of threads being used.
+   */
+  int nthreads() const;
+  
   /*!
    * \brief Perform the filter operation
    *
